﻿--先手工建好数据库，再在建立的数据上执行此建表脚本

IF OBJECT_ID(N'[__EFMigrationsHistory]') IS NULL
BEGIN
    CREATE TABLE [__EFMigrationsHistory] (
        [MigrationId] nvarchar(150) NOT NULL,
        [ProductVersion] nvarchar(32) NOT NULL,
        CONSTRAINT [PK___EFMigrationsHistory] PRIMARY KEY ([MigrationId])
    );
END;

GO

CREATE TABLE [Domain] (
    [Id] uniqueidentifier NOT NULL,
    [ContactPerson] nvarchar(50) NOT NULL,
    [Email] nvarchar(200) NOT NULL,
    [Cellphone] nvarchar(11) NOT NULL,
    [CreateTime] datetime2 NOT NULL,
    CONSTRAINT [PK_Domain] PRIMARY KEY ([Id])
);

GO

CREATE TABLE [Dictionary] (
    [Id] uniqueidentifier NOT NULL,
    [DomainId] uniqueidentifier NOT NULL,
    [Name] nvarchar(100) NOT NULL,
    [Key] nvarchar(100) NOT NULL,
    CONSTRAINT [PK_Dictionary] PRIMARY KEY ([Id]),
    CONSTRAINT [FK_Dictionary_Domain_DomainId] FOREIGN KEY ([DomainId]) REFERENCES [Domain] ([Id]) ON DELETE NO ACTION
);

GO

CREATE TABLE [Organization] (
    [Id] uniqueidentifier NOT NULL,
    [DomainId] uniqueidentifier NOT NULL,
    [ParentId] uniqueidentifier NULL,
    [IdPath] nvarchar(max) NOT NULL,
    [Name] nvarchar(100) NOT NULL,
    [NumericalOrder] int NOT NULL,
    [Removed] bit NOT NULL,
    CONSTRAINT [PK_Organization] PRIMARY KEY ([Id]),
    CONSTRAINT [FK_Organization_Domain_DomainId] FOREIGN KEY ([DomainId]) REFERENCES [Domain] ([Id]) ON DELETE NO ACTION,
    CONSTRAINT [FK_Organization_Organization_ParentId] FOREIGN KEY ([ParentId]) REFERENCES [Organization] ([Id]) ON DELETE NO ACTION
);

GO

CREATE TABLE [ProjectType] (
    [Id] uniqueidentifier NOT NULL,
    [DomainId] uniqueidentifier NOT NULL,
    [Name] nvarchar(200) NOT NULL,
    [Removed] bit NOT NULL,
    CONSTRAINT [PK_ProjectType] PRIMARY KEY ([Id]),
    CONSTRAINT [FK_ProjectType_Domain_DomainId] FOREIGN KEY ([DomainId]) REFERENCES [Domain] ([Id]) ON DELETE NO ACTION
);

GO

CREATE TABLE [Role] (
    [Id] uniqueidentifier NOT NULL,
    [DomainId] uniqueidentifier NOT NULL,
    [Name] nvarchar(100) NOT NULL,
    CONSTRAINT [PK_Role] PRIMARY KEY ([Id]),
    CONSTRAINT [FK_Role_Domain_DomainId] FOREIGN KEY ([DomainId]) REFERENCES [Domain] ([Id]) ON DELETE NO ACTION
);

GO

CREATE TABLE [Settings] (
    [Id] uniqueidentifier NOT NULL,
    [DomainId] uniqueidentifier NOT NULL,
    [WeeklyReportDetailView] bit NOT NULL,
    [WeeklyReportSpentTimeView] bit NOT NULL,
    CONSTRAINT [PK_Settings] PRIMARY KEY ([Id]),
    CONSTRAINT [FK_Settings_Domain_DomainId] FOREIGN KEY ([DomainId]) REFERENCES [Domain] ([Id]) ON DELETE CASCADE
);

GO

CREATE TABLE [Task] (
    [Id] uniqueidentifier NOT NULL,
    [DomainId] uniqueidentifier NOT NULL,
    [Name] nvarchar(100) NOT NULL,
    [CreateTime] datetime2 NOT NULL,
    [Removed] bit NOT NULL,
    CONSTRAINT [PK_Task] PRIMARY KEY ([Id]),
    CONSTRAINT [FK_Task_Domain_DomainId] FOREIGN KEY ([DomainId]) REFERENCES [Domain] ([Id]) ON DELETE NO ACTION
);

GO

CREATE TABLE [DictionaryItem] (
    [Id] uniqueidentifier NOT NULL,
    [DomainId] uniqueidentifier NOT NULL,
    [DictionaryId] uniqueidentifier NOT NULL,
    [Text] nvarchar(100) NOT NULL,
    [Value] int NOT NULL,
    [NumericalOrder] int NOT NULL,
    CONSTRAINT [PK_DictionaryItem] PRIMARY KEY ([Id]),
    CONSTRAINT [FK_DictionaryItem_Dictionary_DictionaryId] FOREIGN KEY ([DictionaryId]) REFERENCES [Dictionary] ([Id]) ON DELETE CASCADE,
    CONSTRAINT [FK_DictionaryItem_Domain_DomainId] FOREIGN KEY ([DomainId]) REFERENCES [Domain] ([Id]) ON DELETE NO ACTION
);

GO

CREATE TABLE [User] (
    [Id] uniqueidentifier NOT NULL,
    [DomainId] uniqueidentifier NOT NULL,
    [OrganizationId] uniqueidentifier NOT NULL,
    [Account] nvarchar(30) NOT NULL,
    [Password] nvarchar(50) NOT NULL,
    [Name] nvarchar(50) NOT NULL,
    [Email] nvarchar(200) NULL,
    [Cellphone] nvarchar(11) NULL,
    [CreateTime] datetime2 NOT NULL,
    [DomainAdmin] bit NOT NULL,
    [Removed] bit NOT NULL,
    CONSTRAINT [PK_User] PRIMARY KEY ([Id]),
    CONSTRAINT [FK_User_Domain_DomainId] FOREIGN KEY ([DomainId]) REFERENCES [Domain] ([Id]) ON DELETE NO ACTION,
    CONSTRAINT [FK_User_Organization_OrganizationId] FOREIGN KEY ([OrganizationId]) REFERENCES [Organization] ([Id]) ON DELETE NO ACTION
);

GO

CREATE TABLE [RoleAuthorization] (
    [Id] uniqueidentifier NOT NULL,
    [DomainId] uniqueidentifier NOT NULL,
    [RoleId] uniqueidentifier NOT NULL,
    [AuthorizationKey] nvarchar(100) NULL,
    CONSTRAINT [PK_RoleAuthorization] PRIMARY KEY ([Id]),
    CONSTRAINT [FK_RoleAuthorization_Domain_DomainId] FOREIGN KEY ([DomainId]) REFERENCES [Domain] ([Id]) ON DELETE NO ACTION,
    CONSTRAINT [FK_RoleAuthorization_Role_RoleId] FOREIGN KEY ([RoleId]) REFERENCES [Role] ([Id]) ON DELETE CASCADE
);

GO

CREATE TABLE [Project] (
    [Id] uniqueidentifier NOT NULL,
    [DomainId] uniqueidentifier NOT NULL,
    [Name] nvarchar(200) NOT NULL,
    [SerialNumber] nvarchar(50) NOT NULL,
    [OwnerUserId] uniqueidentifier NULL,
    [ContractPrice] float NULL,
    [StatusId] uniqueidentifier NULL,
    [CreateTime] datetime2 NOT NULL,
    [Removed] bit NOT NULL,
    CONSTRAINT [PK_Project] PRIMARY KEY ([Id]),
    CONSTRAINT [FK_Project_Domain_DomainId] FOREIGN KEY ([DomainId]) REFERENCES [Domain] ([Id]) ON DELETE NO ACTION,
    CONSTRAINT [FK_Project_User_OwnerUserId] FOREIGN KEY ([OwnerUserId]) REFERENCES [User] ([Id]) ON DELETE NO ACTION,
    CONSTRAINT [FK_Project_DictionaryItem_StatusId] FOREIGN KEY ([StatusId]) REFERENCES [DictionaryItem] ([Id]) ON DELETE NO ACTION
);

GO

CREATE TABLE [RoleUser] (
    [Id] uniqueidentifier NOT NULL,
    [DomainId] uniqueidentifier NOT NULL,
    [RoleId] uniqueidentifier NOT NULL,
    [UserId] uniqueidentifier NOT NULL,
    CONSTRAINT [PK_RoleUser] PRIMARY KEY ([Id]),
    CONSTRAINT [FK_RoleUser_Domain_DomainId] FOREIGN KEY ([DomainId]) REFERENCES [Domain] ([Id]) ON DELETE NO ACTION,
    CONSTRAINT [FK_RoleUser_Role_RoleId] FOREIGN KEY ([RoleId]) REFERENCES [Role] ([Id]) ON DELETE CASCADE,
    CONSTRAINT [FK_RoleUser_User_UserId] FOREIGN KEY ([UserId]) REFERENCES [User] ([Id]) ON DELETE CASCADE
);

GO

CREATE TABLE [WeeklyReport] (
    [Id] uniqueidentifier NOT NULL,
    [DomainId] uniqueidentifier NOT NULL,
    [OrganizationId] uniqueidentifier NOT NULL,
    [UserId] uniqueidentifier NOT NULL,
    [Year] int NOT NULL,
    [Month] int NOT NULL,
    [WeekOfYear] int NOT NULL,
    [Monday] datetime2 NOT NULL,
    [Sunday] datetime2 NOT NULL,
    [Description] nvarchar(2000) NULL,
    [WeeklyReportItem_Task_SpentTime] real NULL,
    [WeeklyReportItem_Project_SpentTime] real NULL,
    CONSTRAINT [PK_WeeklyReport] PRIMARY KEY ([Id]),
    CONSTRAINT [FK_WeeklyReport_Domain_DomainId] FOREIGN KEY ([DomainId]) REFERENCES [Domain] ([Id]) ON DELETE NO ACTION,
    CONSTRAINT [FK_WeeklyReport_Organization_OrganizationId] FOREIGN KEY ([OrganizationId]) REFERENCES [Organization] ([Id]) ON DELETE CASCADE,
    CONSTRAINT [FK_WeeklyReport_User_UserId] FOREIGN KEY ([UserId]) REFERENCES [User] ([Id]) ON DELETE CASCADE
);

GO

CREATE TABLE [WeeklyReportItem_Project] (
    [Id] uniqueidentifier NOT NULL,
    [DomainId] uniqueidentifier NOT NULL,
    [WeeklyReportId] uniqueidentifier NOT NULL,
    [ProjectId] uniqueidentifier NOT NULL,
    [Content] nvarchar(max) NULL,
    [Date] datetime2 NOT NULL,
    [SpentTime] real NULL,
    [NumericalOrder] int NOT NULL,
    CONSTRAINT [PK_WeeklyReportItem_Project] PRIMARY KEY ([Id]),
    CONSTRAINT [FK_WeeklyReportItem_Project_Domain_DomainId] FOREIGN KEY ([DomainId]) REFERENCES [Domain] ([Id]) ON DELETE NO ACTION,
    CONSTRAINT [FK_WeeklyReportItem_Project_Project_ProjectId] FOREIGN KEY ([ProjectId]) REFERENCES [Project] ([Id]) ON DELETE NO ACTION,
    CONSTRAINT [FK_WeeklyReportItem_Project_WeeklyReport_WeeklyReportId] FOREIGN KEY ([WeeklyReportId]) REFERENCES [WeeklyReport] ([Id]) ON DELETE CASCADE
);

GO

CREATE TABLE [WeeklyReportItem_Task] (
    [Id] uniqueidentifier NOT NULL,
    [DomainId] uniqueidentifier NOT NULL,
    [WeeklyReportId] uniqueidentifier NOT NULL,
    [TaskId] uniqueidentifier NOT NULL,
    [Content] nvarchar(max) NULL,
    [Date] datetime2 NOT NULL,
    [SpentTime] real NULL,
    [NumericalOrder] int NOT NULL,
    CONSTRAINT [PK_WeeklyReportItem_Task] PRIMARY KEY ([Id]),
    CONSTRAINT [FK_WeeklyReportItem_Task_Domain_DomainId] FOREIGN KEY ([DomainId]) REFERENCES [Domain] ([Id]) ON DELETE NO ACTION,
    CONSTRAINT [FK_WeeklyReportItem_Task_Task_TaskId] FOREIGN KEY ([TaskId]) REFERENCES [Task] ([Id]) ON DELETE NO ACTION,
    CONSTRAINT [FK_WeeklyReportItem_Task_WeeklyReport_WeeklyReportId] FOREIGN KEY ([WeeklyReportId]) REFERENCES [WeeklyReport] ([Id]) ON DELETE CASCADE
);

GO

CREATE INDEX [IX_Dictionary_DomainId] ON [Dictionary] ([DomainId]);

GO

CREATE INDEX [IX_DictionaryItem_DictionaryId] ON [DictionaryItem] ([DictionaryId]);

GO

CREATE INDEX [IX_DictionaryItem_DomainId] ON [DictionaryItem] ([DomainId]);

GO

CREATE INDEX [IX_Organization_DomainId] ON [Organization] ([DomainId]);

GO

CREATE INDEX [IX_Organization_ParentId] ON [Organization] ([ParentId]);

GO

CREATE INDEX [IX_Project_DomainId] ON [Project] ([DomainId]);

GO

CREATE INDEX [IX_Project_OwnerUserId] ON [Project] ([OwnerUserId]);

GO

CREATE INDEX [IX_Project_StatusId] ON [Project] ([StatusId]);

GO

CREATE INDEX [IX_ProjectType_DomainId] ON [ProjectType] ([DomainId]);

GO

CREATE INDEX [IX_Role_DomainId] ON [Role] ([DomainId]);

GO

CREATE INDEX [IX_RoleAuthorization_DomainId] ON [RoleAuthorization] ([DomainId]);

GO

CREATE INDEX [IX_RoleAuthorization_RoleId] ON [RoleAuthorization] ([RoleId]);

GO

CREATE INDEX [IX_RoleUser_DomainId] ON [RoleUser] ([DomainId]);

GO

CREATE INDEX [IX_RoleUser_RoleId] ON [RoleUser] ([RoleId]);

GO

CREATE INDEX [IX_RoleUser_UserId] ON [RoleUser] ([UserId]);

GO

CREATE INDEX [IX_Settings_DomainId] ON [Settings] ([DomainId]);

GO

CREATE INDEX [IX_Task_DomainId] ON [Task] ([DomainId]);

GO

CREATE INDEX [IX_User_DomainId] ON [User] ([DomainId]);

GO

CREATE INDEX [IX_User_OrganizationId] ON [User] ([OrganizationId]);

GO

CREATE INDEX [IX_WeeklyReport_DomainId] ON [WeeklyReport] ([DomainId]);

GO

CREATE INDEX [IX_WeeklyReport_OrganizationId] ON [WeeklyReport] ([OrganizationId]);

GO

CREATE INDEX [IX_WeeklyReport_UserId] ON [WeeklyReport] ([UserId]);

GO

CREATE INDEX [IX_WeeklyReportItem_Project_DomainId] ON [WeeklyReportItem_Project] ([DomainId]);

GO

CREATE INDEX [IX_WeeklyReportItem_Project_ProjectId] ON [WeeklyReportItem_Project] ([ProjectId]);

GO

CREATE INDEX [IX_WeeklyReportItem_Project_WeeklyReportId] ON [WeeklyReportItem_Project] ([WeeklyReportId]);

GO

CREATE INDEX [IX_WeeklyReportItem_Task_DomainId] ON [WeeklyReportItem_Task] ([DomainId]);

GO

CREATE INDEX [IX_WeeklyReportItem_Task_TaskId] ON [WeeklyReportItem_Task] ([TaskId]);

GO

CREATE INDEX [IX_WeeklyReportItem_Task_WeeklyReportId] ON [WeeklyReportItem_Task] ([WeeklyReportId]);

GO

INSERT INTO [__EFMigrationsHistory] ([MigrationId], [ProductVersion])
VALUES (N'20200326111004_Initialize', N'2.2.6-servicing-10079');

GO

ALTER TABLE [Project] ADD [ProjectTypeId] uniqueidentifier NOT NULL DEFAULT '00000000-0000-0000-0000-000000000000';

GO

CREATE TABLE [ProjectTask] (
    [Id] uniqueidentifier NOT NULL,
    [DomainId] uniqueidentifier NOT NULL,
    [ProjectId] uniqueidentifier NOT NULL,
    [Name] nvarchar(200) NOT NULL,
    [Removed] bit NOT NULL,
    CONSTRAINT [PK_ProjectTask] PRIMARY KEY ([Id]),
    CONSTRAINT [FK_ProjectTask_Domain_DomainId] FOREIGN KEY ([DomainId]) REFERENCES [Domain] ([Id]) ON DELETE NO ACTION,
    CONSTRAINT [FK_ProjectTask_Project_ProjectId] FOREIGN KEY ([ProjectId]) REFERENCES [Project] ([Id]) ON DELETE NO ACTION
);

GO

CREATE INDEX [IX_Project_ProjectTypeId] ON [Project] ([ProjectTypeId]);

GO

CREATE INDEX [IX_ProjectTask_DomainId] ON [ProjectTask] ([DomainId]);

GO

CREATE INDEX [IX_ProjectTask_ProjectId] ON [ProjectTask] ([ProjectId]);

GO

ALTER TABLE [Project] ADD CONSTRAINT [FK_Project_ProjectType_ProjectTypeId] FOREIGN KEY ([ProjectTypeId]) REFERENCES [ProjectType] ([Id]) ON DELETE CASCADE;

GO

INSERT INTO [__EFMigrationsHistory] ([MigrationId], [ProductVersion])
VALUES (N'20200327091313_20200327a', N'2.2.6-servicing-10079');

GO

ALTER TABLE [Project] DROP CONSTRAINT [FK_Project_ProjectType_ProjectTypeId];

GO

DECLARE @var0 sysname;
SELECT @var0 = [d].[name]
FROM [sys].[default_constraints] [d]
INNER JOIN [sys].[columns] [c] ON [d].[parent_column_id] = [c].[column_id] AND [d].[parent_object_id] = [c].[object_id]
WHERE ([d].[parent_object_id] = OBJECT_ID(N'[Project]') AND [c].[name] = N'ProjectTypeId');
IF @var0 IS NOT NULL EXEC(N'ALTER TABLE [Project] DROP CONSTRAINT [' + @var0 + '];');
ALTER TABLE [Project] ALTER COLUMN [ProjectTypeId] uniqueidentifier NULL;

GO

ALTER TABLE [Project] ADD CONSTRAINT [FK_Project_ProjectType_ProjectTypeId] FOREIGN KEY ([ProjectTypeId]) REFERENCES [ProjectType] ([Id]) ON DELETE NO ACTION;

GO

INSERT INTO [__EFMigrationsHistory] ([MigrationId], [ProductVersion])
VALUES (N'20200327095212_20200327b', N'2.2.6-servicing-10079');

GO

ALTER TABLE [WeeklyReportItem_Project] ADD [ProjectTaskId] uniqueidentifier NOT NULL DEFAULT '00000000-0000-0000-0000-000000000000';

GO

CREATE INDEX [IX_WeeklyReportItem_Project_ProjectTaskId] ON [WeeklyReportItem_Project] ([ProjectTaskId]);

GO

ALTER TABLE [WeeklyReportItem_Project] ADD CONSTRAINT [FK_WeeklyReportItem_Project_ProjectTask_ProjectTaskId] FOREIGN KEY ([ProjectTaskId]) REFERENCES [ProjectTask] ([Id]) ON DELETE CASCADE;

GO

INSERT INTO [__EFMigrationsHistory] ([MigrationId], [ProductVersion])
VALUES (N'20200408063913_20200408a', N'2.2.6-servicing-10079');

GO

ALTER TABLE [WeeklyReport] ADD [AttachedFiles] nvarchar(1000) NULL;

GO

INSERT INTO [__EFMigrationsHistory] ([MigrationId], [ProductVersion])
VALUES (N'20200514031017_20200514a', N'2.2.6-servicing-10079');

GO

ALTER TABLE [WeeklyReportItem_Task] ADD [Month] int NOT NULL DEFAULT 0;

GO

ALTER TABLE [WeeklyReportItem_Task] ADD [Year] int NOT NULL DEFAULT 0;

GO

ALTER TABLE [WeeklyReportItem_Project] ADD [Month] int NOT NULL DEFAULT 0;

GO

ALTER TABLE [WeeklyReportItem_Project] ADD [Year] int NOT NULL DEFAULT 0;

GO

INSERT INTO [__EFMigrationsHistory] ([MigrationId], [ProductVersion])
VALUES (N'20200522082917_20200522a', N'2.2.6-servicing-10079');

GO

DECLARE @var1 sysname;
SELECT @var1 = [d].[name]
FROM [sys].[default_constraints] [d]
INNER JOIN [sys].[columns] [c] ON [d].[parent_column_id] = [c].[column_id] AND [d].[parent_object_id] = [c].[object_id]
WHERE ([d].[parent_object_id] = OBJECT_ID(N'[Settings]') AND [c].[name] = N'WeeklyReportDetailView');
IF @var1 IS NOT NULL EXEC(N'ALTER TABLE [Settings] DROP CONSTRAINT [' + @var1 + '];');
ALTER TABLE [Settings] DROP COLUMN [WeeklyReportDetailView];

GO

DECLARE @var2 sysname;
SELECT @var2 = [d].[name]
FROM [sys].[default_constraints] [d]
INNER JOIN [sys].[columns] [c] ON [d].[parent_column_id] = [c].[column_id] AND [d].[parent_object_id] = [c].[object_id]
WHERE ([d].[parent_object_id] = OBJECT_ID(N'[Settings]') AND [c].[name] = N'WeeklyReportSpentTimeView');
IF @var2 IS NOT NULL EXEC(N'ALTER TABLE [Settings] DROP CONSTRAINT [' + @var2 + '];');
ALTER TABLE [Settings] DROP COLUMN [WeeklyReportSpentTimeView];

GO

ALTER TABLE [Settings] ADD [WeeklyReportPostCondition] int NOT NULL DEFAULT 0;

GO

INSERT INTO [__EFMigrationsHistory] ([MigrationId], [ProductVersion])
VALUES (N'20200610072837_20200610a', N'2.2.6-servicing-10079');

GO

ALTER TABLE [WeeklyReportItem_Project] ADD [ProjectStatusId] uniqueidentifier NULL;

GO

CREATE INDEX [IX_WeeklyReportItem_Project_ProjectStatusId] ON [WeeklyReportItem_Project] ([ProjectStatusId]);

GO

ALTER TABLE [WeeklyReportItem_Project] ADD CONSTRAINT [FK_WeeklyReportItem_Project_DictionaryItem_ProjectStatusId] FOREIGN KEY ([ProjectStatusId]) REFERENCES [DictionaryItem] ([Id]) ON DELETE NO ACTION;

GO

INSERT INTO [__EFMigrationsHistory] ([MigrationId], [ProductVersion])
VALUES (N'20200805060504_20200805a', N'2.2.6-servicing-10079');

GO

